@@ -1,12 +1,17 @@
-from pyrsistent import pset
+from pyrsistent import pset, s
 import pytest
 
 
+def test_literalish_works():
+    assert s() is pset()
+    assert s(1, 2) == pset([1, 2])
+
+
 def test_contains_elements_that_it_was_initialized_with():
     initial = [1, 2, 3]
     s = pset(initial)
 
-    assert s.toset() == set(initial)
+    assert set(s) == set(initial)
     assert len(s) == len(set(initial))
 
 
@@ -14,12 +19,12 @@ def test_is_immutable():
     s1 = pset([1])
     s2 = s1.add(2)
 
-    assert s1.toset() == set([1])
-    assert s2.toset() == set([1, 2])
+    assert set(s1) == set([1])
+    assert set(s2) == set([1, 2])
 
     s3 = s2.without(1)
-    assert s2.toset() == set([1, 2])
-    assert s3.toset() == set([2])
+    assert set(s2) == set([1, 2])
+    assert set(s3) == set([2])
 
 
 def test_is_iterable():
@@ -46,6 +51,6 @@ def test_behaves_set_like():
 
 
 def test_str():
-    assert str(pset([1, 2, 3])) == "set([1, 2, 3])"
+    assert str(pset([1, 2, 3])) == "pset([1, 2, 3])"
 
-pytest.main()
\ No newline at end of file
+pytest.main()
